@@ -384,6 +384,7 @@ MatchLoop:
 
 		// For any meta data from decoding
 		var metaTags []string
+		currentLine := ""
 
 		// Check if the decoded portions of the segment overlap with the match
 		// to see if its potentially a new match
@@ -391,6 +392,7 @@ MatchLoop:
 			if segment := segmentWithDecodedOverlap(encodedSegments, matchIndex[0], matchIndex[1]); segment != nil {
 				matchIndex = segment.adjustMatchIndex(matchIndex)
 				metaTags = append(metaTags, segment.tags()...)
+				currentLine = segment.currentLine(currentRaw)
 			} else {
 				// This item has already been added to a finding
 				continue
@@ -433,6 +435,10 @@ MatchLoop:
 			continue
 		}
 
+		if currentLine == "" {
+			currentLine = finding.Line
+		}
+
 		// Set the value of |secret|, if the pattern contains at least one capture group.
 		// (The first element is the full match, hence we check >= 2.)
 		groups := r.Regex.FindStringSubmatch(finding.Secret)
@@ -474,7 +480,7 @@ MatchLoop:
 		case "match":
 			globalAllowlistTarget = finding.Match
 		case "line":
-			globalAllowlistTarget = finding.Line
+			globalAllowlistTarget = currentLine
 		}
 		if d.Config.Allowlist.RegexAllowed(globalAllowlistTarget) {
 			logger.Trace().
@@ -496,7 +502,7 @@ MatchLoop:
 			case "match":
 				allowlistTarget = finding.Match
 			case "line":
-				allowlistTarget = finding.Line
+				allowlistTarget = currentLine
 			}
 
 			var (
@@ -568,8 +574,8 @@ func allTrue(bools []bool) bool {
 	return allMatch
 }
 
-// addFinding synchronously adds a finding to the findings slice
-func (d *Detector) addFinding(finding report.Finding) {
+// AddFinding synchronously adds a finding to the findings slice
+func (d *Detector) AddFinding(finding report.Finding) {
 	globalFingerprint := fmt.Sprintf("%s:%s:%d", finding.File, finding.RuleID, finding.StartLine)
 	if finding.Commit != "" {
 		finding.Fingerprint = fmt.Sprintf("%s:%s:%s:%d", finding.Commit, finding.File, finding.RuleID, finding.StartLine)
@@ -609,7 +615,12 @@ func (d *Detector) addFinding(finding report.Finding) {
 	d.findingMutex.Unlock()
 }
 
-// addCommit synchronously adds a commit to the commit slice
+// Findings returns the findings added to the detector
+func (d *Detector) Findings() []report.Finding {
+	return d.findings
+}
+
+// AddCommit synchronously adds a commit to the commit slice
 func (d *Detector) addCommit(commit string) {
 	d.commitMap[commit] = true
 }
