@@ -62,7 +62,7 @@ func (d *Detector) DetectGit(cmd *sources.GitCmd, remote *RemoteInfo) ([]report.
 					}
 
 					for _, finding := range d.Detect(fragment) {
-						d.addFinding(augmentGitFinding(remote, finding, textFragment, gitdiffFile))
+						d.AddFinding(augmentGitFinding(remote, finding, textFragment, gitdiffFile))
 					}
 				}
 				return nil
@@ -171,6 +171,8 @@ func platformFromHost(u *url.URL) scm.Platform {
 		return scm.GitHubPlatform
 	case "gitlab.com":
 		return scm.GitLabPlatform
+	case "dev.azure.com", "visualstudio.com":
+		return scm.AzureDevOpsPlatform
 	default:
 		return scm.UnknownPlatform
 	}
